@@ -18,7 +18,7 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-"""Use pikepdf to find links in a PDF"""
+"""Use pikepdf to find links in a PDF."""
 
 import argparse
 
